@@ -1,6 +1,7 @@
 from sklearn.pipeline import Pipeline
 
 from .. import nodes as local_nodes
+from ... import models
 from ...abstract import AbstractPipelineFactory
 
 
@@ -14,11 +15,13 @@ class CoverageStatisticsFactory(AbstractPipelineFactory):
         Returns:
         sklear.pipeline.Pipeline: Scikit-learn pipeline
         """
+        pivots = models.DataFramePivotFields()
+        defaults = models.DefaultValues()
         return Pipeline(
             [
                 (
                     "coverage_stats_estimator",
-                    local_nodes.CoverageStatistics(),
+                    local_nodes.CoverageStatistics(pivots=pivots, defaults=defaults),
                 ),
             ],
         )
