@@ -1,5 +1,5 @@
 from ...abstract import AbstractNode
-from ...models import DataContainer
+from ...models import LinkerDataContainer
 from ...models import DataFramePivotFields
 
 
@@ -8,10 +8,10 @@ _PRIMARY_KEY = _PIVOT_FIELDS.clusters_pk
 
 
 class Precision(AbstractNode):
-    def fit(self, X: DataContainer, y=None):
+    def fit(self, X: LinkerDataContainer, y=None):
         return self
 
-    def transform(self, X: DataContainer):
+    def transform(self, X: LinkerDataContainer):
         n_cluster_pkeys = X.clusters[_PRIMARY_KEY].nunique()
         n_join_pkeys = X.clusters_plan_join[_PRIMARY_KEY].nunique()
         return n_join_pkeys / n_cluster_pkeys
